"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Describe = void 0;

var _react = _interopRequireWildcard(require("react"));

var _utility = require("../utility");

var _Test = require("./Test");

var _DescribeContext = require("./DescribeContext");

var Describe = function Describe(_ref) {
  var name = _ref.name,
      children = _ref.children,
      _ref$verbose = _ref.verbose,
      verbose = _ref$verbose === void 0 ? false : _ref$verbose;
  // The describe context allows <Test /> components to inject a test into a
  // this describe block. Since the `describe()` calls are immediate and non
  // async, we must emit the `describe()` once we have the expected number of
  // tests from the counter above.
  var describeContext = (0, _react.useMemo)(function () {
    var listOfJestTestFunctions = [];
    var expectedNumberOfJestTestsInDescribe = 0;
    var numberOfJestTestsFound = 0; // Find number of direct children in node that are <Test /> functions.
    // This will create an expected subtotal that will be used to create the
    // Describe block, once rendered.

    _react["default"].Children.forEach(children, function (child) {
      // @ts-ignore
      if (child.type === _Test.Test) {
        expectedNumberOfJestTestsInDescribe++;
      }
    }); // This is the function available to the <Test /> components.


    var push = function push(nameOfTest, testBodyFunction) {
      // If we're in the browser, exit early.
      if (!_utility.jestIsActive) {
        return;
      } // Every time <Test /> calls this push method we increment.


      numberOfJestTestsFound++; // First we push the item onto the list.

      listOfJestTestFunctions.push({
        name: nameOfTest,
        testBodyFunction: testBodyFunction
      }); // Emit once we have the expected number of tests.

      if (numberOfJestTestsFound === expectedNumberOfJestTestsInDescribe) {
        // This is a normal describe call, looping through the test functions.
        // This will be read correctly by Jest when you render the React
        // component as static HTML.
        describe(name, function () {
          listOfJestTestFunctions.forEach(function (fn) {
            test(fn.name, fn.testBodyFunction);
          });
        });
      }
    }; // The return of the describe context is our push function above and
    // whether or not the context is active (i.e. command line or browser.)


    return {
      push: push,
      active: _utility.jestIsActive,
      verbose: verbose
    };
  }, [children, name, verbose]);
  return _react["default"].createElement(_DescribeContext.DescribeContext.Provider, {
    value: describeContext
  }, _react["default"].createElement("section", {
    className: "describe"
  }, _react["default"].createElement("h2", {
    className: "describe__name"
  }, name), _react["default"].createElement("div", {
    className: "describe__tests"
  }, children)));
};

exports.Describe = Describe;