"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Test = void 0;

var _react = _interopRequireWildcard(require("react"));

var _useErrorBoundary2 = require("use-error-boundary");

var _DescribeContext = require("./DescribeContext");

var _utility = require("../utility");

var _TestContext = require("./TestContext");

var Test = function Test(_ref) {
  var name = _ref.name,
      _ref$verbose = _ref.verbose,
      verbose = _ref$verbose === void 0 ? false : _ref$verbose,
      children = _ref.children;
  var describeCtx = (0, _react.useContext)(_DescribeContext.DescribeContext);
  var testCtx = (0, _react.useContext)(_TestContext.TestContext);

  var _useErrorBoundary = (0, _useErrorBoundary2.useErrorBoundary)(),
      ErrorBoundary = _useErrorBoundary.ErrorBoundary,
      error = _useErrorBoundary.error,
      errorInfo = _useErrorBoundary.errorInfo;

  var testContext = (0, _react.useMemo)(function () {
    var listOfFuncs = [];

    if (_utility.jestIsActive) {
      var testFunc = function testFunc(cb) {
        Promise.all(listOfFuncs.map(function (func) {
          return func();
        })).then(function () {
          return cb();
        });
      };

      if (testCtx.active) {
        testCtx.push(function () {
          test(name, testFunc);
        });
      } else if (describeCtx.active) {
        describeCtx.push(name, testFunc);
      } else {
        test(name, testFunc);
      }
    }

    var push = function push(func) {
      listOfFuncs.push(func);
    };

    return {
      push: push,
      active: _utility.jestIsActive,
      verbose: verbose
    };
  }, [describeCtx, name, testCtx, verbose]);
  return _react["default"].createElement(_TestContext.TestContext.Provider, {
    value: testContext
  }, _react["default"].createElement("article", {
    className: "test ".concat(error ? 'test--error' : '')
  }, _react["default"].createElement("h4", {
    className: "test__name"
  }, name), error ? _react["default"].createElement("div", {
    className: "test__error"
  }, _react["default"].createElement("code", null, _react["default"].createElement("pre", null, error.toString()), _react["default"].createElement("pre", null, (0, _utility.parseError)(errorInfo)))) : _react["default"].createElement(ErrorBoundary, null, children)));
};

exports.Test = Test;