"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.shouldReturnBoolean = shouldReturnBoolean;
exports.filterFuncName = filterFuncName;
exports.runTest = runTest;
exports.runTests = runTests;
exports.parseError = parseError;
exports.useIsVerbose = exports.jestIsActive = void 0;

var _toArray2 = _interopRequireDefault(require("@babel/runtime/helpers/esm/toArray"));

var _react = require("react");

var _DescribeContext = require("./components/DescribeContext");

var _TestContext = require("./components/TestContext");

// @ts-ignore
var jestIsActive = typeof global.it === 'function';
exports.jestIsActive = jestIsActive;

var useIsVerbose = function useIsVerbose() {
  var describeCtx = (0, _react.useContext)(_DescribeContext.DescribeContext);
  var testCtx = (0, _react.useContext)(_TestContext.TestContext);
  return describeCtx.verbose || testCtx.verbose;
};

exports.useIsVerbose = useIsVerbose;

function shouldReturnBoolean(key, value) {
  if (key === 'toThrow' || key === 'toBeUndefined') {
    return false;
  }

  return true;
}

function filterFuncName(name) {
  // Unwrap anonymous function with single return (compiled arrow)
  if (name.match(/function \(\) {\s+return /)) {
    var _name$split = name.split('return'),
        _name$split2 = (0, _toArray2["default"])(_name$split),
        _$ = _name$split2[0],
        parts = _name$split2.slice(1);

    return parts.join('').slice(0, -1).trim();
  }

  return name;
}

function runTest(element) {
  return runTests([element]);
}

function runTests(elements) {
  if (!jestIsActive) return;
  var error;

  try {
    var _iteratorNormalCompletion = true;
    var _didIteratorError = false;
    var _iteratorError = undefined;

    try {
      for (var _iterator = elements[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
        var element = _step.value;

        require('react-dom/server').renderToStaticMarkup(element);
      }
    } catch (err) {
      _didIteratorError = true;
      _iteratorError = err;
    } finally {
      try {
        if (!_iteratorNormalCompletion && _iterator["return"] != null) {
          _iterator["return"]();
        }
      } finally {
        if (_didIteratorError) {
          throw _iteratorError;
        }
      }
    }
  } catch (err) {
    error = err;
  }

  describe('Dynamic JSX tests', function () {
    test('All Dynamic tests loaded successfully', function () {
      expect(error).toBeUndefined();
    });
  });
}

function parseError(errorInfo) {
  return errorInfo.componentStack.split('\n').filter(function (s) {
    return !s.match(/in Call/) && !s.match(/in ErrorBoundary/) && !s.match(/in UseErrorBoundaryWrapper/) && !s.match(/in Assertion/) && !s.match(/in article \(at Test\.tsx/) && !s.match(/in section \(at Describe\.tsx/);
  }).join('\n');
}